==> aroundme_0_5_0.tar.tgz: aroundme_0_5_0/aroundme/language/1/barnraiser_01/sch_edit_task.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


// SECTION
$lang['section_schedule'] = 					"add or edit a task";


//HEADER
$lang['hdr_schedule'] = 						"add or edit a task";
$lang['hdr_group_schedule'] = 					"add or edit a group task for group 'GROUPTITLE'.";


// FORMS
$lang['form_no_start'] = 						"This task has no start date and time";
$lang['form_no_end'] = 							"This task has no end date and time";
$lang['form_label_comments'] = 					"Check to allow people to add comments to this task";


//BODY TEXT
$lang['txt_publish_node_help'] =				"The task will be submitted to Splash editor and can be viewed by any member of this community.";
$lang['txt_publish_public_help'] =				"The task will be submitted to web site editor and can be viewed by anyone.";
$lang['txt_publish_help'] =						"How wide do you want the audience of your task to be? You can publish to just your friends, wider degrees of acquaintances or the Splash magazine page.";
$lang['txt_header_1'] = 						"1. Task overview";
$lang['txt_overview_intro'] = 					"You can add a task to this community. A task is a thing to do. Add a small synopsis which is a one line description of the task to be used when displaying it in lists.";
$lang['txt_date_intro'] = 						"Enter a start and end date and time for your task. You can use the popup calendar to enter a date and time or just type on in. The format is important. Please type the date as yyyy-dd-mm and the time as hh:mm.";
$lang['txt_image_intro'] = 						"A thumbnail (small) picture can be shown next to the task on all lists. Choose one from the list below if desired.";
$lang['txt_publishing_intro'] = 				"Choose where you would like this task to be published to.";


//$lang['form_label_title'] = 					"Title";
//$lang['form_label_synopsis'] = 					"Synopsis";
//$lang['form_label_location'] = 					"Location";
//$lang['form_label_start_date'] = 				"From date";
//$lang['form_label_end_date'] = 					"To date";
//$lang['form_label_start_time'] = 				"From time";
//$lang['form_label_end_time'] = 					"To time";
//$lang['form_label_category'] = 					"Category";
//$lang['form_label_status'] = 					"Status";
//$lang['form_label_priority'] = 					"Priority";
//$lang['form_label_complete'] = 					"Complete";
//$lang['form_label_file'] = 						"thumbnail image";
//$lang['form_rsp_group'] = 						"Check to submit this to the web site editor for inclusion on the group home page.";
//$lang['form_rsp_node'] = 						"Check to submit this to the node editor for inclusion in Splash.";
//$lang['form_rsp_group_auto'] = 					"Check to add this to the group home page.";
//$lang['form_rsp_node_auto'] = 					"Check to add this to Splash.";
//$lang['form_body'] = 							"details";
//$lang['form_submit_save_go'] = 					"SAVE AND GO";
//$lang['form_submit_save'] = 					"SAVE";
//$lang['form_submit_preview'] = 					"preview";
//$lang['form_label_preview'] = 					"preview";
//ERRORS
//$lang['err_schedule_item_edit'] = 				"Sorry, you can only edit your schedule items.";
// HREF
//$lang['href_information'] = 					"?";
//$lang['txt_check_spelling'] = 					"check spelling";
//$lang['txt_publish_level'] =					"everyone";
//$lang['txt_header_2'] = 						"2. Date and time";
//$lang['txt_header_4'] = 						"4. Thumbnail image";
//$lang['txt_header_3'] = 						"3. Details";
//$lang['txt_detail_intro'] = 					"Add any details that you wish people to know. What do you want done, what skills are required and what your goal is are all examples.";
//$lang['txt_header_5'] = 						"5. Publishing";
//$lang['txt_none'] = 							"none";
//$lang['txt_header_6'] = 						"6. Save";
//$lang['txt_save_intro'] = 						"Save your work. 'save and go' will take you to the details page.";

?>

==> aroundme_0_6_2.tar.tgz: aroundme_0_6_2/aroundme/language/1/barnraiser_01/sch_edit_task.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'sch_view.lang.php');

// SECTION
$lang['hdr_schedule'] = 						"add or edit a task";


//HEADER
$lang['hdr_schedule'] = 						"add or edit a task";
$lang['hdr_group_schedule'] = 					"add or edit a group task for group 'GROUPTITLE'.";


// FORMS
$lang['form_no_start'] = 						"This task has no start date and time";
$lang['form_no_end'] = 							"This task has no end date and time";
$lang['form_label_comments'] = 					"Check to allow people to add comments to this task";


//BODY TEXT
$lang['txt_header_1'] = 						"1. Task overview";
$lang['txt_overview_intro'] = 					"You can add a task to this community. A task is a thing to do. Add a small synopsis which is a one line description of the task to be used when displaying it in lists.";
$lang['txt_date_intro'] = 						"Enter a start and end date and time for your task. You can use the popup calendar to enter a date and time or just type on in. The format is important. Please type the date as yyyy-dd-mm and the time as hh:mm.";
$lang['txt_image_intro'] = 						"A thumbnail (small) picture can be shown next to the task on all lists. Choose one from the list below if desired.";
$lang['txt_publishing_intro'] = 				"Choose where you would like this task to be published to.";

?>
